@@ -22,10 +22,17 @@ extern void __assert_fail (const char *__assertion, const char *__file,
 #ifdef NDEBUG
 #define assert(expr)
 #else
+#ifdef expect
+# define assert(expr)							      \
+  ((void) (expect((int)expr,0) ? 0 :					      \
+	   (__assert_fail (#expr,				      \
+			   __FILE__, __LINE__, __ASSERT_FUNCTION), 0)))
+#else
 # define assert(expr)							      \
   ((void) ((expr) ? 0 :							      \
 	   (__assert_fail (#expr,				      \
 			   __FILE__, __LINE__, __ASSERT_FUNCTION), 0)))
 #endif
+#endif
 
 #endif
