@@ -7,6 +7,9 @@
 #define RTLD_LOCAL	0x00000
 #define RTLD_GLOBAL	0x10000
 
+#define RTLD_DEFAULT	((void*)1)
+#define RTLD_NEXT	((void*)2)
+
 void *dlopen (const char *filename, int flag);
 const char *dlerror(void);
 void *dlsym(void *handle, char *symbol);
