@@ -3,8 +3,7 @@
 
 #include <endian.h>
 
-#ifdef __GNUC__
-#if (__GNUC__ > 2) || (__GNUC__ == 2) && (__GNUC_MINOR__ > 96)
+#if (__GNUC__ > 2) || ((__GNUC__ == 2) && (__GNUC_MINOR__ >= 96))
 
 typedef __builtin_va_list va_list;
 #define va_start(v,l)	__builtin_stdarg_start((v),l)
@@ -12,7 +11,6 @@ typedef __builtin_va_list va_list;
 #define va_arg		__builtin_va_arg
 #define __va_copy(d,s)	__builtin_va_copy((d),(s))
 
-#endif
 #endif
 
 #ifndef va_end
