@@ -14,7 +14,7 @@ int memccmp(const void *s1, const void *s2, int c, size_t n) __THROW __pure__;
 /* gcc unfortunately has some internal prototypes that are not compliant
  * to the single unix specification and if we define the correct
  * prototypes here, gcc emits warnings. */
-#if !defined(__GNUC__) || defined(__mips__) || defined(__alpha__) || defined(__arm__) || defined(__x86_64__)
+#if __GNUC__ > 2 || defined(__mips__) || defined(__alpha__) || defined(__arm__) || defined(__x86_64__)
 void* memset(void *s, int c, size_t n) __THROW;
 int memcmp(const void *s1, const void *s2, size_t n) __THROW __pure__;
 void* memcpy(void *dest, const void *src, size_t n) __THROW;
@@ -31,9 +31,6 @@ char *strncat(char *dest, const char *src, size_t n) __THROW;
 
 int strcmp(const char *s1, const char *s2) __THROW __pure__;
 
-int strcasecmp(const char *s1, const char *s2) __THROW __pure__;
-int strncasecmp(const char *s1, const char *s2, size_t n) __THROW __pure__;
-
 size_t strlen(const char *s) __THROW __pure__;
 
 char *strstr(const char *haystack, const char *needle) __THROW __pure__;
@@ -65,13 +62,13 @@ char *strerror(int errnum) __THROW;
 #ifdef _GNU_SOURCE
 const char *strsignal(int signum) __THROW;
 void *memmem(const void *haystack, size_t haystacklen, const void *needle, size_t needlelen) __THROW;
+
+char *strndup(const char *s,size_t n) __attribute_malloc__ __THROW;
 #endif
 
 char *strtok(char *s, const char *delim) __THROW;
 char *strtok_r(char *s, const char *delim, char **ptrptr) __THROW;
 
-int ffs(int i) __THROW __attribute__((__const__));
-
 size_t strlcpy(char *dst, const char *src, size_t size) __THROW;
 size_t strlcat(char *dst, const char *src, size_t size) __THROW;
 
@@ -79,11 +76,7 @@ int strcoll(const char *s1, const char *s2) __THROW;
 size_t strxfrm(char *dest, const char *src, size_t n) __THROW;
 
 #ifdef _BSD_SOURCE
-#define bzero(s,n) memset(s,0,n)
-#define bcopy(src,dest,n) memmove(dest,src,n)
-#define bcmp(a,b,n) memcmp(a,b,n)
-#define index(a,b) strchr(a,b)
-#define rindex(a,b) strrchr(a,b)
+#include <strings.h>
 #endif
 
 char *stpcpy(char *dest, const char *src);
