@@ -21,6 +21,23 @@
 
 #define PTRACE_SYSCALL		  24
 
+#define PT_TRACE_ME		PTRACE_TRACEME
+#define PT_READ_I		PTRACE_PEEKTEXT
+#define PT_READ_D		PTRACE_PEEKDATA
+#define PT_READ_U		PTRACE_READ_U
+#define PT_WRITE_I		PTRACE_POKETEXT
+#define PT_WRITE_D		PTRACE_POKEDATA
+#define PT_WRITE_U		PTRACE_POKEUSER
+#define PT_CONTINUE		PTRACE_CONT
+#define PT_KILL			PTRACE_KILL
+#define PT_STEP			PTRACE_SINGLESTEP
+#define PT_GETREGS		PTRACE_GETREGS
+#define PT_SETREGS		PTRACE_SETREGS
+#define PT_GETFPREGS		PTRACE_GETFPREGS
+#define PT_SETFPREGS		PTRACE_SETFPREGS
+#define PT_ATTACH		PTRACE_ATTACH
+#define PT_DETACH		PTRACE_DETACH
+
 #if defined(__i386__)
 #define EBX 0
 #define ECX 1
