@@ -48,12 +48,16 @@ again:
 	return ':';
       }
       ++optind;
-    } else ++lastofs;
+    } else {
+      ++lastofs;
+      return optopt;
+    }
 found:
     ++optind;
     return optopt;
   } else {	/* not found */
     getopterror(0);
+    ++optind;
     return '?';
   }
 }
