@@ -1,4 +1,4 @@
-#include <string.h>
+#include <strings.h>
 
 int  strcasecmp ( const char* s1, const char* s2 )
 {
