@@ -1,5 +1,5 @@
 #include <sys/types.h>
-#include <string.h>
+#include <strings.h>
 
 int  strncasecmp ( const char* s1, const char* s2, size_t len )
 {
