@@ -9,14 +9,16 @@
  * the last written bytes is always '\0'. */
 #endif
 
+/* gcc is broken and has a non-SUSv2 compliant internal prototype.
+ * This causes it to warn about a type mismatch here.  Ignore it. */
 char *strncat(char *s, const char *t, size_t n) {
   char *dest=s;
   register char *max;
   s+=strlen(s);
 #ifdef WANT_NON_COMPLIANT_STRNCAT
-  max=s+n-1;
+  if ((max=s+n-1)<=s) goto fini;
 #else
-  max=s+n;
+  if ((max=s+n)==s) goto fini;
 #endif
   for (;;) {
     if (!(*s = *t)) break; if (++s==max) break; ++t;
@@ -27,5 +29,6 @@ char *strncat(char *s, const char *t, size_t n) {
 #endif
   }
   *s=0;
+fini:
   return dest;
 }
