@@ -25,11 +25,11 @@ void *malloc(size_t size) {
   return ret;
 }
 
-void* realloc(void* ptr, size_t size) { /* the code is not thread-save */
+void* realloc(void* ptr, size_t size) {
   register void *ret;
   __NO_ASYNC_CANCEL_BEGIN;
   pthread_mutex_lock(&mutex_alloc);
-  __libc_realloc(ptr, size);
+  ret=__libc_realloc(ptr, size);
   pthread_mutex_unlock(&mutex_alloc);
   __NO_ASYNC_CANCEL_END;
   return ret;
